@@ -22,14 +22,16 @@ SOFTWARE.'''
 
 import os
 
+from . import numerics
+from . import constants
+
 from . import atmosphere
 from . import compressible
-from . import control_valve
 from . import core
+from . import friction
 from . import filters
 from . import fittings
 from . import flow_meter
-from . import friction
 from . import geometry
 from . import mixing
 from . import open_flow
@@ -38,13 +40,14 @@ from . import piping
 from . import pump
 from . import safety_valve
 from . import packed_tower
-from . import two_phase
 from . import two_phase_voidage
+from . import two_phase
 from . import drag
 from . import saltation
 from . import separator
 from . import particle_size_distribution
 from . import jet_pump
+from . import control_valve
 
 
 from .atmosphere import *
@@ -83,6 +86,7 @@ __all__.extend(compressible.__all__)
 __all__.extend(control_valve.__all__)
 __all__.extend(core.__all__)
 __all__.extend(filters.__all__)
+
 __all__.extend(fittings.__all__)
 __all__.extend(friction.__all__)
 __all__.extend(geometry.__all__)
@@ -103,8 +107,8 @@ __all__.extend(particle_size_distribution.__all__)
 __all__.extend(jet_pump.__all__)
 
 
-__version__ = '0.1.73'
+__version__ = '0.1.75'
 
 fluids_dir = os.path.dirname(__file__)
-fluids_data_dir = os.path.join(os.path.dirname(__file__), 'data')
+fluids_data_dir = os.path.join(fluids_dir, 'data')
 
