@@ -21,11 +21,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
 from __future__ import division
-from math import log, pi, exp
-import numpy as np
-from scipy.optimize import newton, ridder
-from scipy.constants import R
-from scipy.special import lambertw
+from math import log, pi, exp, isinf
+from fluids.constants import R
+from fluids.numerics import newton, ridder, lambertw
 
 __all__ = ['Panhandle_A', 'Panhandle_B', 'Weymouth', 'Spitzglass_high',
            'Spitzglass_low', 'Oliphant', 'Fritzsche', 'Muller', 'IGT', 'isothermal_gas',
@@ -93,7 +91,7 @@ def isothermal_work_compression(P1, P2, T, Z=1):
     Examples
     --------
     >>> isothermal_work_compression(1E5, 1E6, 300)
-    5743.425357533477
+    5743.427304244769
 
     References
     ----------
@@ -191,7 +189,7 @@ def isentropic_work_compression(T1, k, Z=1, P1=None, P2=None, W=None, eta=None):
     Examples
     --------
     >>> isentropic_work_compression(P1=1E5, P2=1E6, T1=300, k=1.4, eta=0.78)
-    10416.873455626454
+    10416.876986384483
 
     References
     ----------
@@ -865,14 +863,12 @@ inlet pressure; fluid will flow backwards.')
             # Consider the two real branches of the lambertw function.
             # The k=-1 branch produces the higher P2 values; the k=0 branch is
             # physically impossible.
-            lambert_ans = float(lambertw(arg,k=-1).real)
+            lambert_ans = float(lambertw(arg, k=-1).real)
             # Large overflow problem here; also divide by zero problems!
             # Fail and try a numerical solution if it doesn't work.
-            assert np.isfinite(lambert_ans)
+            assert not math.isinf(lambert_ans)
             P2 = P1/exp((-C*m**2+lambert_ans*m**2+B*P1)/m**2/2.)
             assert P2 < P1
-            
-
             return P2
         except:
             Pcf = P_isothermal_critical_flow(P=P1, fd=fd, D=D, L=L)
