@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 '''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2016, 2017, 2018 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -21,9 +21,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
 from __future__ import division
-from math import sin, exp, pi
-from scipy.constants import g, R
-import numpy as np
+from math import sin, exp, pi, fabs, copysign
+from fluids.constants import g, R
+from fluids.numerics import numpy as np
 
 __all__ = ['Reynolds', 'Prandtl', 'Grashof', 'Nusselt', 'Sherwood', 'Rayleigh',
 'Schmidt', 'Peclet_heat', 'Peclet_mass', 'Fourier_heat', 'Fourier_mass',
@@ -34,7 +34,9 @@ __all__ = ['Reynolds', 'Prandtl', 'Grashof', 'Nusselt', 'Sherwood', 'Rayleigh',
 'relative_roughness', 'nu_mu_converter', 'gravity',
 'K_from_f', 'K_from_L_equiv', 'L_equiv_from_K', 'L_from_K', 'dP_from_K', 
 'head_from_K', 'head_from_P',
-'P_from_head', 'Eotvos']
+'P_from_head', 'Eotvos',
+]
+
 
 ### Not quite dimensionless groups
 def thermal_diffusivity(k, rho, Cp):
@@ -108,7 +110,7 @@ def c_ideal_gas(T, k, MW):
     Examples
     --------
     >>> c_ideal_gas(T=303, k=1.4, MW=28.96)
-    348.9820361755092
+    348.9820953185441
 
     References
     ----------
@@ -2908,55 +2910,3 @@ def Engauge_2d_parser(lines, flat=False):
     return z_values, x_lists, y_lists
 
 
-def horner(coeffs, x):
-    r'''Evaluates a polynomial defined by coefficienfs `coeffs` at a specified
-    scalar `x` value, using the horner method. This is the most efficient 
-    formula to evaluate a polynomial (assuming non-zero coefficients for all
-    terms). This has been added to the `fluids` library because of the need to
-    frequently evaluate polynomials; and `NumPy`'s polyval is actually quite 
-    slow for scalar values.
-    
-    Note that the coefficients are reversed compared to the common form; the
-    first value is the coefficient of the highest-powered x term, and the last
-    value in `coeffs` is the constant offset value.
-
-    Parameters
-    ----------
-    coeffs : iterable[float]
-        Coefficients of polynomial, [-]
-    x : float
-        Point at which to evaluate the polynomial, [-]
-
-    Returns
-    -------
-    val : float
-        The evaluated value of the polynomial, [-]
-
-    Notes
-    -----
-    For maximum speed, provide a list of Python floats and `x` should also be
-    of type `float` to avoid either `NumPy` types or slow python ints. 
-
-    Compare the speed with numpy via:
-        
-    >>> coeffs = np.random.uniform(0, 1, size=15)
-    >>> coeffs_list = coeffs.tolist()
-    
-    %timeit np.polyval(coeffs, 10.0)
-    
-    `np.polyval` takes on the order of 15 us; `horner`, 1 us.
-    
-    Examples
-    --------
-    >>> horner([1.0, 3.0], 2.0)
-    5.0
-
-    References
-    ----------
-    .. [1] "Horner’s Method." Wikipedia, October 6, 2018. 
-    https://en.wikipedia.org/w/index.php?title=Horner%27s_method&oldid=862709437.
-    '''
-    tot = 0.0
-    for c in coeffs:
-        tot = tot*x + c
-    return tot
