@@ -22,11 +22,10 @@ SOFTWARE.'''
 
 from __future__ import division
 from math import exp, log, log10, tanh
-import numpy as np
-from scipy.constants import g
-from scipy.optimize import newton
-from scipy.integrate import odeint, cumtrapz
+from fluids.constants import g
+from fluids.numerics import newton
 from fluids.core import Reynolds
+from fluids.numerics import numpy as np
 
 __all__ = ['drag_sphere', 'v_terminal', 'integrate_drag_sphere',
 'time_v_terminal_Stokes', 'Stokes',
@@ -158,11 +157,17 @@ def Barati_high(Re):
        Evolutionary Approach." Powder Technology 257 (May 2014): 11-19.
        doi:10.1016/j.powtec.2014.02.045.
     '''
-    Cd = (8E-6*((Re/6530.)**2 + tanh(Re) - 8*log(Re)/log(10.))
-    - 0.4119*exp(-2.08E43/(Re+Re**2)**4)
-    - 2.1344*exp(-((log(Re**2 + 10.7563)/log(10))**2 + 9.9867)/Re)
-    + 0.1357*exp(-((Re/1620.)**2 + 10370.)/Re)
-    - 8.5E-3*(2*log(tanh(tanh(Re)))/log(10) - 2825.7162)/Re + 2.4795)
+    Re2 = Re*Re
+    t0 = 1.0/Re
+    t1 = (Re/6530.)
+    t2 = (Re/1620.)
+    t3 = log10(Re2 + 10.7563)
+    tanhRe = tanh(Re)
+    Cd = (8E-6*(t1*t1 + tanhRe - 8.0*log10(Re))
+    - 0.4119*exp(-2.08E43/(Re+Re2)**4)
+    - 2.1344*exp(-t0*(t3*t3 + 9.9867))
+    + 0.1357*exp(-t0*(t2*t2 + 10370.))
+    - 8.5E-3*t0*(2.0*log10(tanh(tanhRe)) - 2825.7162) + 2.4795)
     return Cd
 
 
@@ -1393,6 +1398,9 @@ def integrate_drag_sphere(D, rhop, rho, mu, t, V=0, Method=None,
     # For an accurate integration of the particle's distance traveled
     pts = 1000 if distance else 2
     ts = np.linspace(0, t, pts)
+    
+    # Delayed import of necessaray functions
+    from scipy.integrate import odeint, cumtrapz
 
     # Perform the integration
     Vs = odeint(dv_dt, [V], ts)
