@@ -22,11 +22,10 @@ SOFTWARE.'''
 
 from __future__ import division
 from math import cos, sin, tan, atan, pi, radians, exp, acos, log10
-import numpy as np
 from fluids.friction import friction_factor
 from fluids.core import Froude_densimetric
-from scipy.optimize import newton, brenth
-from scipy.constants import g, inch
+from fluids.numerics import interp, secant, py_brenth as brenth
+from fluids.constants import g, inch
 
 __all__ = ['C_Reader_Harris_Gallagher',
            'differential_pressure_meter_solver',
@@ -132,9 +131,10 @@ def flow_meter_discharge(D, Do, P1, P2, rho, C, expansibility=1.0):
        Differential Devices Inserted in Circular Cross-Section Conduits Running
        Full -- Part 2: Orifice Plates.
     '''
-    dP = P1 - P2
     beta = Do/D
-    return (pi*Do*Do/4.)*C*(2*dP*rho)**0.5/(1.0 - beta**4)**0.5*expansibility
+    beta2 = beta*beta
+    return (0.25*pi*Do*Do)*C*expansibility*(
+            (2.0*rho*(P1 - P2))/(1.0 - beta2*beta2))**0.5
 
 
 def orifice_expansibility(D, Do, P1, P2, k):
@@ -187,7 +187,9 @@ def orifice_expansibility(D, Do, P1, P2, k):
        Full -- Part 2: Orifice Plates.
     '''
     beta = Do/D
-    return (1.0 - (0.351 + 0.256*beta**4 + 0.93*beta**8)*(
+    beta2 = beta*beta
+    beta4 = beta2*beta2
+    return (1.0 - (0.351 + beta4*(0.93*beta4 + 0.256))*(
             1.0 - (P2/P1)**(1./k)))
 
 
@@ -278,7 +280,8 @@ def C_Reader_Harris_Gallagher(D, Do, rho, mu, m, taps='corner'):
         Re_D = \frac{\rho v D}{\mu}
         
         
-    If D < 71.12 mm (2.8 in.):
+    If D < 71.12 mm (2.8 in.) (Note this is a continuous addition; there is no
+    discontinuity):
         
     .. math::
         C += 0.11(0.75-\beta)\left(2.8-\frac{D}{0.0254}\right)
@@ -370,9 +373,10 @@ def C_Reader_Harris_Gallagher(D, Do, rho, mu, m, taps='corner'):
     .. [4] Reader-Harris, Michael. Orifice Plates and Venturi Tubes. Springer, 
        2015.
     '''
-    A_pipe = pi/4.*D*D
+    A_pipe = 0.25*pi*D*D
     v = m/(A_pipe*rho)
     Re_D = rho*v*D/mu
+    Re_D_inv = 1.0/Re_D
     
     beta = Do/D
     if taps == 'corner':
@@ -389,25 +393,30 @@ def C_Reader_Harris_Gallagher(D, Do, rho, mu, m, taps='corner'):
     beta4 = beta2*beta2
     beta8 = beta4*beta4
     
-    A = (19000.0*beta/Re_D)**0.8
-    M2_prime = 2*L2_prime/(1.0 - beta)
+    A = (19000.0*beta*Re_D_inv)**0.8
+    M2_prime = 2.0*L2_prime/(1.0 - beta)
     
     delta_C_upstream = ((0.043 + 0.080*exp(-1E1*L1) - 0.123*exp(-7.0*L1))
             *(1.0 - 0.11*A)*beta4/(1.0 - beta4))
     
     # The max part is not in the ISO standard
+    t1 = log10(3700.*Re_D_inv)
+    if t1 < 0.0:
+        t1 = 0.0
     delta_C_downstream = (-0.031*(M2_prime - 0.8*M2_prime**1.1)*beta**1.3
-                          *(1.0 + 8*max(log10(3700./Re_D), 0.0)))
+                          *(1.0 + 8.0*t1))
     
     # C_inf is discharge coefficient with corner taps for infinite Re
     # Cs, slope term, provides increase in discharge coefficient for lower
     # Reynolds numbers.
-    
+    x1 = (1E6*Re_D_inv)**0.3
+    x2 = 22.7 - 0.0047*Re_D
+    t2 = x1 if x1 > x2 else x2
     # max term is not in the ISO standard
     C_inf_C_s = (0.5961 + 0.0261*beta2 - 0.216*beta8 
-                 + 0.000521*(1E6*beta/Re_D)**0.7
+                 + 0.000521*(1E6*beta*Re_D_inv)**0.7
                  + (0.0188 + 0.0063*A)*beta**3.5*(
-                 max((1E6/Re_D)**0.3, 22.7 - 4700.0*(Re_D/1E6))))
+                 t2))
     
     C = (C_inf_C_s + delta_C_upstream + delta_C_downstream)
     if D < 0.07112:
@@ -416,7 +425,11 @@ def C_Reader_Harris_Gallagher(D, Do, rho, mu, m, taps='corner'):
         # Suggested to be required not becausue of any effect of small
         # diameters themselves, but because of edge radius differences.
         # max term is given in [4]_ Reader-Harris, Michael book
-        delta_C_diameter = 0.011*(0.75 - beta)*max((2.8 - D/0.0254), 0.0)
+        # There is a check for t3 being negative and setting it to zero if so
+        # in some sources but that only occurs when t3 is exactly the limit
+        # (0.07112) so it is not needed
+        t3 = (2.8 - D/0.0254)
+        delta_C_diameter = 0.011*(0.75 - beta)*t3
         C += delta_C_diameter
     
     return C
@@ -468,7 +481,8 @@ def discharge_coefficient_to_K(D, Do, C):
     beta = Do/D
     beta2 = beta*beta
     beta4 = beta2*beta2
-    return ((1.0 - beta4*(1.0 - C*C))**0.5/(C*beta2) - 1.0)**2
+    root_K = ((1.0 - beta4*(1.0 - C*C))**0.5/(C*beta2) - 1.0)
+    return root_K*root_K
 
 
 def K_to_discharge_coefficient(D, Do, K):
@@ -520,8 +534,7 @@ def K_to_discharge_coefficient(D, Do, K):
     beta2 = beta*beta
     beta4 = beta2*beta2
     root_K = K**0.5
-    common_term = 2.0*root_K*beta4 + K*beta4
-    return (-beta4/(common_term) + 1.0/(common_term))**0.5
+    return ((1.0 - beta4)/(2.0*root_K*beta4 + K*beta4))**0.5
 
 
 def dP_orifice(D, Do, P1, P2, C):
@@ -885,18 +898,16 @@ def C_venturi_nozzle(D, Do):
 # low high losses corresponding to large diameters
 # Interpolation can be performed.
 
-venturi_tube_betas = np.array(
-        [0.299160, 0.299470, 0.312390, 0.319010, 0.326580, 0.337290, 
+venturi_tube_betas = [0.299160, 0.299470, 0.312390, 0.319010, 0.326580, 0.337290, 
           0.342020, 0.347060, 0.359030, 0.365960, 0.372580, 0.384870, 
           0.385810, 0.401250, 0.405350, 0.415740, 0.424250, 0.434010, 
           0.447880, 0.452590, 0.471810, 0.473090, 0.493540, 0.499240,
           0.516530, 0.523800, 0.537630, 0.548060, 0.556840, 0.573890,
           0.582350, 0.597820, 0.601560, 0.622650, 0.626490, 0.649480, 
           0.650990, 0.668700, 0.675870, 0.688550, 0.693180, 0.706180, 
-          0.713330, 0.723510, 0.749540, 0.749650])
+          0.713330, 0.723510, 0.749540, 0.749650]
             
-venturi_tube_dP_high = np.array(
-        [0.164534, 0.164504, 0.163591, 0.163508, 0.163439,
+venturi_tube_dP_high = [0.164534, 0.164504, 0.163591, 0.163508, 0.163439,
         0.162652, 0.162224, 0.161866, 0.161238, 0.160786,
         0.160295, 0.159280, 0.159193, 0.157776, 0.157467, 
         0.156517, 0.155323, 0.153835, 0.151862, 0.151154, 
@@ -905,10 +916,9 @@ venturi_tube_dP_high = np.array(
         0.127637, 0.124758, 0.124006, 0.119269, 0.118449,
         0.113605, 0.113269, 0.108995, 0.107109, 0.103688, 
         0.102529, 0.099567, 0.097791, 0.095055, 0.087681, 
-        0.087648])
+        0.087648]
             
-venturi_tube_dP_low = np.array(
-    [0.089232, 0.089218, 0.088671, 0.088435, 0.088206,
+venturi_tube_dP_low = [0.089232, 0.089218, 0.088671, 0.088435, 0.088206,
    0.087853, 0.087655, 0.087404, 0.086693, 0.086241,
    0.085813, 0.085142, 0.085102, 0.084446, 0.084202, 
    0.083301, 0.082470, 0.081650, 0.080582, 0.080213, 
@@ -917,10 +927,10 @@ venturi_tube_dP_low = np.array(
    0.063298, 0.060872, 0.060378, 0.057879, 0.057403, 
    0.054091, 0.053879, 0.051726, 0.050931, 0.049362, 
    0.048675, 0.046522, 0.045381, 0.043840, 0.039913, 
-   0.039896])
+   0.039896]
             
 #ratios_average = 0.5*(ratios_high + ratios_low)
-D_bound_venturi_tube = np.array([0.065, 0.5])
+D_bound_venturi_tube = [0.065, 0.5]
 
 
 def dP_venturi_tube(D, Do, P1, P2):
@@ -978,9 +988,9 @@ def dP_venturi_tube(D, Do, P1, P2):
     '''
     # Effect of Re is not currently included
     beta = Do/D
-    epsilon_D65 = np.interp(beta, venturi_tube_betas, venturi_tube_dP_high)
-    epsilon_D500 = np.interp(beta, venturi_tube_betas, venturi_tube_dP_low)
-    epsilon = np.interp(D, D_bound_venturi_tube, [epsilon_D65, epsilon_D500])
+    epsilon_D65 = interp(beta, venturi_tube_betas, venturi_tube_dP_high)
+    epsilon_D500 = interp(beta, venturi_tube_betas, venturi_tube_dP_low)
+    epsilon = interp(D, D_bound_venturi_tube, [epsilon_D65, epsilon_D500])
     return epsilon*(P1 - P2)
 
 
@@ -1230,12 +1240,12 @@ def C_wedge_meter_Miller(D, H):
     beta = diameter_ratio_wedge_meter(D, H)
     if D <= 0.7*inch:
         # suggested limit 0.5 inch for this equation
-        C = 0.7883 + 0.107*(1 - beta*beta)
+        C = 0.7883 + 0.107*(1.0 - beta*beta)
     elif D <= 1.4*inch:
         # Suggested limit is under 1.5 inches
-        C = 0.6143 + 0.718*(1 - beta*beta)
+        C = 0.6143 + 0.718*(1.0 - beta*beta)
     else:
-        C = 0.5433 + 0.2453*(1 - beta*beta)
+        C = 0.5433 + 0.2453*(1.0 - beta*beta)
     return C
 
 
@@ -1674,8 +1684,8 @@ def differential_pressure_meter_C_epsilon(D, D2, m, P1, P2, rho, mu, k,
     (0.6151252900244296, 0.9711026966676307)
     '''
     if meter_type == ISO_5167_ORIFICE:
-        C = C_Reader_Harris_Gallagher(D=D, Do=D2, rho=rho, mu=mu, m=m, taps=taps)
-        epsilon = orifice_expansibility(D=D, Do=D2, P1=P1, P2=P2, k=k)
+        C = C_Reader_Harris_Gallagher(D, D2, rho, mu, m, taps)
+        epsilon = orifice_expansibility(D, D2, P1, P2, k)
     elif meter_type == LONG_RADIUS_NOZZLE:
         epsilon = nozzle_expansibility(D=D, Do=D2, P1=P1, P2=P2, k=k)
         C = C_long_radius_nozzle(D=D, Do=D2, rho=rho, mu=mu, m=m)
@@ -1775,23 +1785,30 @@ def differential_pressure_meter_solver(D, rho, mu, k, D2=None, P1=None, P2=None,
     >>> differential_pressure_meter_solver(D=0.07366, D2=0.05, P1=200000.0, 
     ... P2=183000.0, rho=999.1, mu=0.0011, k=1.33, 
     ... meter_type='ISO 5167 orifice', taps='D')
-    7.702338035732168
+    7.702338035732167
     
     >>> differential_pressure_meter_solver(D=0.07366, m=7.702338, P1=200000.0, 
     ... P2=183000.0, rho=999.1, mu=0.0011, k=1.33, 
     ... meter_type='ISO 5167 orifice', taps='D')
     0.04999999990831885
     '''
-    if m is None:
-        def to_solve(m):
+    if m is None and None not in (D, D2, P1, P2):
+        
+        def to_solve(m_D):
+            m = m_D*D
             epsilon, C = differential_pressure_meter_C_epsilon(D, D2, m, P1, P2, rho, 
                                                           mu, k, meter_type, 
                                                           taps=taps)
             m_calc = flow_meter_discharge(D=D, Do=D2, P1=P1, P2=P2, rho=rho, 
                                         C=C, expansibility=epsilon)
-            return m - m_calc
-        return newton(to_solve, 2.81)
-    elif D2 is None:
+            err =  m - m_calc
+            return err
+        # Diameter to mass flow ratio
+        m_D_guess = 40
+        if rho < 100.0:
+            m_D_guess *= 1e-2
+        return secant(to_solve, m_D_guess)*D
+    elif D2 is None and None not in (D, m, P1, P2):
         def to_solve(D2):
             epsilon, C = differential_pressure_meter_C_epsilon(D, D2, m, P1, P2, rho, 
                                                           mu, k, meter_type, 
@@ -1800,7 +1817,7 @@ def differential_pressure_meter_solver(D, rho, mu, k, D2=None, P1=None, P2=None,
                                         C=C, expansibility=epsilon)
             return m - m_calc    
         return brenth(to_solve, D*(1-1E-9), D*5E-3)
-    elif P2 is None:
+    elif P2 is None and None not in (D, D2, m, P1):
         def to_solve(P2):
             epsilon, C = differential_pressure_meter_C_epsilon(D, D2, m, P1, P2, rho, 
                                                           mu, k, meter_type, 
@@ -1809,7 +1826,7 @@ def differential_pressure_meter_solver(D, rho, mu, k, D2=None, P1=None, P2=None,
                                         C=C, expansibility=epsilon)
             return m - m_calc    
         return brenth(to_solve, P1*(1-1E-9), P1*0.5)
-    elif P1 is None:
+    elif P1 is None and None not in (D, D2, m, P2):
         def to_solve(P1):
             epsilon, C = differential_pressure_meter_C_epsilon(D, D2, m, P1, P2, rho, 
                                                           mu, k, meter_type, 
@@ -1819,7 +1836,7 @@ def differential_pressure_meter_solver(D, rho, mu, k, D2=None, P1=None, P2=None,
             return m - m_calc    
         return brenth(to_solve, P2*(1+1E-9), P2*1.4)
     else:
-        raise Exception('Solver is capable of solving for one of P2, D2, or m only.')
+        raise ValueError('Solver is capable of solving for one of P2, D2, or m only.')
     
 
 def differential_pressure_meter_dP(D, D2, P1, P2, C=None, 
