@@ -22,10 +22,9 @@ SOFTWARE.'''
 
 from __future__ import division
 from math import exp, log, pi, sin, cos, radians
-from scipy.constants import g
+from fluids.constants import g
 from fluids.core import Froude
 
-
 __all__ = ['Thom', 'Zivi', 'Smith', 'Fauske', 'Chisholm_voidage', 'Turner_Wallis',
            'homogeneous', 'Chisholm_Armand', 'Armand', 'Nishino_Yamazaki',
            'Guzhov', 'Kawahara', 'Baroczy', 'Tandon_Varma_Gupta', 'Harms',
