@@ -169,6 +169,15 @@ def convert_input(val, unit, ureg, strict=True):
         else:
             return val
 
+pint_expression_cache = {}
+
+def parse_expression_cached(unit, ureg):
+    if unit in pint_expression_cache:
+        return pint_expression_cache[unit]
+    ans = ureg.parse_expression(unit)
+    pint_expression_cache[unit] = ans
+    return ans
+    
 
 def convert_output(result, out_units, out_vars, ureg):
     # Attempt to handle multiple return values
@@ -179,15 +188,15 @@ def convert_output(result, out_units, out_vars, ureg):
     elif t == dict:
         for key, ans in result.items():
             unit = out_units[out_vars.index(key)]
-            result[key] = ans*ureg.parse_expression(unit)
+            result[key] = ans*parse_expression_cached(unit, ureg)
         return result
     elif isinstance(result, collections.Iterable):
         conveted_result = []
         for ans, unit in zip(result, out_units):
-            conveted_result.append(ans*ureg.parse_expression(unit))
+            conveted_result.append(ans*parse_expression_cached(unit, ureg))
         return conveted_result
     else:
-        return result*ureg.parse_expression(out_units[0])
+        return result*parse_expression_cached(out_units[0], ureg)
 
 
 def wraps_numpydoc(ureg, strict=True):    
@@ -275,7 +284,7 @@ class UnitAwareClass(object):
         try:
             value = getattr(self.wrapped, name)
         except Exception as e:
-            raise Exception('Failed to get property %s with error %s' %(str(name), str(e)))
+            raise AttributeError('Failed to get property %s with error %s' %(str(name), str(e)))
         if value is not None:
             if name in self.property_units:
                 if type(value) == dict:
@@ -305,7 +314,7 @@ class UnitAwareClass(object):
                         return convert_output(result, out_units, out_vars, self.ureg)
                         
                     return call_func_with_inputs_to_SI
-                raise Exception('Error: Property does not yet have units attached')
+                raise AttributeError('Error: Property does not yet have units attached')
         else:
             return value
         
@@ -378,10 +387,10 @@ def wrap_numpydoc_obj(obj_to_wrap):
             property_unit_map.update({var:u(unit) for var, unit in zip(parsed['Parameters']['vars'], parsed['Parameters']['units'])} )
 
     name = obj_to_wrap.__name__
-    locals()[name] = type(name, (UnitAwareClass,), 
+    fun = type(name, (UnitAwareClass,), 
            {'wrapped': obj_to_wrap, #'__doc__': obj_to_wrap.__doc__,
             'property_units': property_unit_map, 'method_units': callable_methods})
-    return locals()[name]
+    return fun
 
 
 __funcs = {}
@@ -397,6 +406,10 @@ for name in dir(fluids):
         obj = wraps_numpydoc(u)(obj)
     elif type(obj) == type:
         obj = wrap_numpydoc_obj(obj)
+    elif type(obj) is types.ModuleType:
+        # Functions accessed with the namespace like friction.friction_factor
+        # would call the original function - leads to user confusion if they are exposed
+        continue
     elif isinstance(obj, str):
         continue
     if name == '__all__':
