@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 '''Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2016, 2017 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2016, 2017, 2018 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -24,6 +24,7 @@ from __future__ import division
 from fluids import *
 from numpy.testing import assert_allclose, assert_equal
 import pytest
+import numpy as np
 
 def test_core_misc():
     alpha = thermal_diffusivity(0.02, 1., 1000.)
@@ -300,8 +301,4 @@ def test_rankine_to_celcius():
 def test_rankine_to_kelvin():
     assert_allclose(R2K([491.67, 0.]), [273.15, 0.], rtol=0., atol=1e-13)
     
-    
-def test_horner():
-    from fluids.core import horner
-    assert_allclose(horner([1.0, 3.0], 2.0), 5.0)
-    assert_allclose(horner([3.0], 2.0), 3.0)
\ No newline at end of file
+    
\ No newline at end of file
